pub struct ASCOMError {
pub code: ASCOMErrorCode,
pub message: Cow<'static, str>,
}Expand description
ASCOM error.
Fields
code: ASCOMErrorCodeError number.
message: Cow<'static, str>Error message.
Implementations
Sourceimpl ASCOMError
impl ASCOMError
Sourcepub fn new(code: ASCOMErrorCode, message: impl Display) -> Self
pub fn new(code: ASCOMErrorCode, message: impl Display) -> Self
Create a new ASCOMError from given error code and a message.
Sourceimpl ASCOMError
impl ASCOMError
Sourcepub const NOT_IMPLEMENTED: Self
pub const NOT_IMPLEMENTED: Self
Property or method not implemented.
Sourcepub const INVALID_VALUE: Self
pub const INVALID_VALUE: Self
Invalid value.
Sourcepub const VALUE_NOT_SET: Self
pub const VALUE_NOT_SET: Self
A value has not been set.
Sourcepub const NOT_CONNECTED: Self
pub const NOT_CONNECTED: Self
The communications channel is not connected.
Sourcepub const INVALID_WHILE_PARKED: Self
pub const INVALID_WHILE_PARKED: Self
The attempted operation is invalid because the mount is currently in a Parked state.
Sourcepub const INVALID_WHILE_SLAVED: Self
pub const INVALID_WHILE_SLAVED: Self
The attempted operation is invalid because the mount is currently in a Slaved state.
Sourcepub const INVALID_OPERATION: Self
pub const INVALID_OPERATION: Self
The requested operation can not be undertaken at this time.
Sourcepub const ACTION_NOT_IMPLEMENTED: Self
pub const ACTION_NOT_IMPLEMENTED: Self
The requested action is not implemented in this driver.
Sourcepub const OPERATION_CANCELLED: Self
pub const OPERATION_CANCELLED: Self
In-progress asynchronous operation has been cancelled.
Sourceimpl ASCOMError
impl ASCOMError
Sourcepub fn invalid_operation(message: impl Display) -> Self
pub fn invalid_operation(message: impl Display) -> Self
Create a new “invalid operation” error with the specified message.
Sourcepub fn invalid_value(message: impl Display) -> Self
pub fn invalid_value(message: impl Display) -> Self
Create a new “invalid value” error with the specified message.